# -*- coding: utf-8 -*-
"""THIS ENTIRE MODULE/FOLDER IS DEPRECATED!
IT HAS TO BE REMOVED IN THE NEXT VERSION OF THIS ADD-ON.
IT'S HERE JUST TO PREVENT UNWANTED ERRORS WHILE UPGRADING FROM THE PREVIOUS
VERSION!
TODO
"""
import logging
from zope.i18nmessageid import MessageFactory

_ = MessageFactory('collective.smartlink')
logger = logging.getLogger(__name__)
